import {
  APICreate,
  APIListPaginated,
  APIRemove,
  APIRetrieve,
  APIUpdate,
  createExtendableAPI,
} from '@rokoli/bnb/drf'
import { defineStore } from 'pinia'

import { createSteeringURL } from '@/api'
import { steeringAuthInit } from '@/stores/auth'
import { Note } from '@/types'
import { aggregateWithIdsParameter } from '@/util/api'

type ReadonlyAttrs = 'id' | 'createdAt' | 'createdBy' | 'updatedAt' | 'updatedBy' | 'ownerId'
type NoteCreateData = Omit<Note, ReadonlyAttrs>
type NoteUpdateData = Partial<Omit<Note, ReadonlyAttrs>>

export const useNoteStore = defineStore('notes', () => {
  const endpoint = createSteeringURL.prefix('notes')
  const { api, base } = createExtendableAPI<Note>(endpoint, steeringAuthInit)
  const listOperations = APIListPaginated(api)
  return {
    ...base,
    ...listOperations,
    ...APIRetrieve(api, {
      aggregate: aggregateWithIdsParameter(listOperations.listIsolated),
    }),
    ...APICreate<Note, NoteCreateData>(api),
    ...APIUpdate<Note, NoteUpdateData>(api),
    ...APIRemove(api),
  }
})
