import {
  APICreate,
  APIListPaginated,
  APIRemove,
  APIRetrieve,
  APIUpdate,
  createExtendableAPI,
} from '@rokoli/bnb/drf'
import { defineStore } from 'pinia'

import { createSteeringURL } from '@/api'
import { components } from '@/steering-types'
import { steeringAuthInit } from '@/stores/auth'
import { KeysFrom, Profile } from '@/types'

type ReadonlyAttrs = KeysFrom<Profile, 'id'>
type ProfileUpdateData = Omit<Profile, ReadonlyAttrs>
type ProfilePartialUpdateData = components['schemas']['PatchedProfile']

export const useProfileStore = defineStore('profiles', () => {
  const endpoint = createSteeringURL.prefix('profiles')
  const { api, base } = createExtendableAPI<Profile>(endpoint, steeringAuthInit)
  return {
    ...base,
    ...APIListPaginated(api),
    ...APIRetrieve(api),
    ...APICreate(api),
    ...APIUpdate<Profile, ProfileUpdateData, ProfilePartialUpdateData>(api),
    ...APIRemove(api),
  }
})
