import { createUnpaginatedAPIStore } from '@/stores/util'
import { ImageFrameSpec, RadioSettings } from '@/types'
import { createSteeringURL } from '@/api'
import { steeringAuthInit } from '@/stores/auth'
import { computed, MaybeRefOrGetter, toValue } from 'vue'

export const useRadioSettingsStore = createUnpaginatedAPIStore<RadioSettings>(
  'radio-settings',
  createSteeringURL.prefix('settings'),
  steeringAuthInit,
  { syncOnAuth: true },
)

export function useCurrentRadioSettings() {
  const radioStore = useRadioSettingsStore()
  return computed<RadioSettings | null>(() => radioStore.items?.[0] ?? null)
}

export function useImageRequirements(
  key: keyof RadioSettings['imageRequirements'],
  radioSettings?: MaybeRefOrGetter<RadioSettings | null>,
) {
  radioSettings = radioSettings ?? useCurrentRadioSettings()
  return computed(() => {
    const requirements = toValue(radioSettings)?.imageRequirements[key]
    if (!requirements) return null
    return { frame: requirements.frame as Required<ImageFrameSpec> }
  })
}
