import { APIObject, IsolatedPaginatedListOperation } from '@rokoli/bnb'
import { APIRetrieveAggregator } from '@rokoli/bnb/drf'

type APIRetrieveAggregatorOptions = Parameters<typeof APIRetrieveAggregator>[1]
const AGGRAGATE_MAX_QUEUE_COUNT: number = 100

export function aggregateWithIdsParameter<T extends APIObject>(
  list: IsolatedPaginatedListOperation<T>,
  config: APIRetrieveAggregatorOptions | undefined = undefined,
) {
  const configuredMaxQueueCount = Math.round(config?.maxQueueCount ?? AGGRAGATE_MAX_QUEUE_COUNT)
  const queueCount = Math.min(configuredMaxQueueCount, AGGRAGATE_MAX_QUEUE_COUNT)
  if (configuredMaxQueueCount > queueCount) {
    console.warn(
      `Maximum queue count is capped at ${AGGRAGATE_MAX_QUEUE_COUNT}. You’ve specified ${configuredMaxQueueCount}.`,
    )
  }

  return APIRetrieveAggregator<T>(
    async (ids, options) => {
      const { items } = await list(1, {
        limit: queueCount,
        requestInit: options?.requestInit,
        query: new URLSearchParams({ ids: ids.join(',') }),
      })
      return items
    },
    { ...(config ?? {}), maxQueueCount: queueCount },
  )
}
